// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.controllers' is found in controllers.js
angular.module('gemfest', ['ionic','ionic.service.core','ionic.service.push','gemfest.services', 'pascalprecht.translate', 'gemfest.controllers', 'ion-alpha-scroll', 'ion-gallery', 'ngSanitize', 'ngCordova', 'ionic.ion.autoListDivider'])

  .run(function ($ionicPlatform, PUSH_NOTIFICATIONS,$state, $rootScope) {
    var data = {
      lang: 'en',
      notifications: true,
      time: "30",
      sound: false,
      reminder: true
    };

    if (window.localStorage.getItem('settings') == null) {
      window.localStorage.setItem('settings', angular.toJson(data));
    }


    PUSH_NOTIFICATIONS.init();
    $ionicPlatform.ready(function () {
      cordova.plugins.notification.local.on("click", function(notification) {
        var data = JSON.parse(notification.data);
        var type = data.type;
        var urlId = data.urlId;
        if(type == 'artists')
          $state.go("app.artist", { 'artistId': urlId });
        else
          $state.go("app.activity", { 'activityId': urlId });
      });
      $rootScope.$on('$cordovaPush:notificationReceived', function(event, notification){
        console.log(event);
        console.log(notification);
      });

      // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
      // for form inputs)
      if (window.cordova && window.cordova.plugins.Keyboard) {
        cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
        cordova.plugins.Keyboard.disableScroll(true);

      }
      if (window.StatusBar) {
        // org.apache.cordova.statusbar required
        StatusBar.styleDefault();
      }
    });
  })

  .config(function ($translateProvider) {

    $translateProvider.translations('en', {
      SETTINGS: 'SETTINGS',
      HOME: 'HOME',
      LANGUAGES: 'Languages',
      NOTIFICATION_TIME: 'Notification Time',
      NOTIFICATIONS: 'Notifications',
      SOUND: 'Sound',
      PRIVACY_POLICY: 'Privacy Policy',
      REMINDER: 'Reminder',
      HOME_MENU: 'Home',
      LINEUP: 'Lineup',
      ACTIVITIES: 'Activities',
      SCHEDULE: 'Schedule',
      MAP: 'Map',
      NEWS: 'News',
      GALLERY: 'Gallery',
      SOCIAL_MEDIA: 'Social Media',
      ARTISTS: 'ARTISTS',
      PHOTOS: 'Photo',
      VIDEOS: 'Video',
      FAVOURITES: 'Favourites',
      SUBSCRIBED: 'Subscribed',
      LINKS: 'Links'
    });

    $translateProvider.translations('ka', {
      SETTINGS: 'პარამერტრები',
      HOME: 'მთავარი',
      LANGUAGES: 'ენები',
      NOTIFICATION_TIME: 'ნოტიფიკაციის დრო',
      NOTIFICATIONS: 'ნოტიფიკაციები',
      SOUND: 'ხმა',
      REMINDER: 'შეხსენება',
      PRIVACY_POLICY: 'წესები',
      HOME_MENU: 'მთავარი',
      LINEUP: 'Lineup',
      ACTIVITIES: 'აქტივობები',
      SCHEDULE: 'განრიგი',
      MAP: 'რუქა',
      NEWS: 'სიახლეები',
      GALLERY: 'გალერეა',
      SOCIAL_MEDIA: 'სოციალური ქსელი',
      ARTISTS: 'არტისტები',
      PHOTOS: 'ფოტო',
      VIDEOS: 'ვიდეო',
      FAVOURITES: 'ფავორიტები',
      SUBSCRIBED: 'ფავორიტები',
      LINKS: 'ბმულები'
    });

    $translateProvider.translations('ru', {
      SETTINGS: 'настройки',
      HOME: 'Главная',
      LANGUAGES: 'языки',
      NOTIFICATION_TIME: 'время уведомления',
      NOTIFICATIONS: 'уведомления',
      SOUND: 'звук',
      REMINDER: 'напоминание',
      PRIVACY_POLICY: 'политика конфиденциальности',
      HOME_MENU: 'Главная',
      LINEUP: 'Lineup',
      ACTIVITIES: 'Мероприятия',
      SCHEDULE: 'График',
      MAP: 'Карта',
      NEWS: 'Новости',
      GALLERY: 'Галерея',
      SOCIAL_MEDIA: 'Социальный сеть',
      ARTISTS: 'Исполнители',
      PHOTOS: 'Фото',
      VIDEOS: 'видео',
      FAVOURITES: 'фавориты',
      SUBSCRIBED: 'Подписки',
      LINKS: 'Подписки'
    });
    var settings = angular.fromJson(window.localStorage.getItem('settings'));
    console.log(settings);
    if (settings) {
      $translateProvider.preferredLanguage(settings.lang);
    } else {
      $translateProvider.preferredLanguage('en');
    }
    ;

    $translateProvider.useSanitizeValueStrategy('escape');

  })
  .config(function($httpProvider){
    delete $httpProvider.defaults.headers.common['X-Requested-With'];
  })

  .config(function ($stateProvider, $urlRouterProvider, $ionicConfigProvider) {
    $ionicConfigProvider.tabs.position('top');
    $stateProvider

      .state('app', {
        url: '/app',
        abstract: true,
        templateUrl: 'templates/menu.html',
        controller: 'AppCtrl'
      })
      .state('app.home', {
        url: '/home',
        views: {
          'menuContent': {
            templateUrl: 'templates/home.html',
            controller: 'homeCtrl'
          }
        }
      })
      .state('app.lineup', {
        url: '/lineup',
        views: {
          'menuContent': {
            templateUrl: 'templates/lineup.html',
            controller: 'lineupCtrl'
          }
        }
      })
      .state('app.artist', {
        url: '/lineup/:artistId',
        views: {
          'menuContent': {
            templateUrl: 'templates/artist.html',
            controller: 'artistCtrl'
          }
        }
      })
      .state('app.settings', {
        url: '/settings',
        views: {
          'menuContent': {
            templateUrl: 'templates/settings.html',
            controller: 'settingsCtrl'
          }
        }
      })

      .state('app.events', {
        url: '/events',
        views: {
          'menuContent': {
            templateUrl: 'templates/events.html',
            controller: 'eventsCtrl'
          }
        }
      })
      .state('app.single', {
        url: '/events/:eventId',
        views: {
          'menuContent': {
            templateUrl: 'templates/event.html',
            controller: 'eventCtrl'
          }
        }
      })
      .state('app.schedule', {
        url: '/schedule',
        views: {
          'menuContent': {
            templateUrl: 'templates/schedule.html',
            controller: 'scheduleCtrl'
          }
        }
      })

      .state('app.map', {
        url: '/map',
        views: {
          'menuContent': {
            templateUrl: 'templates/map.html',
            controller: 'mapCtrl'
          }
        }
      })

      .state('app.activities', {
        url: '/activities',
        views: {
          'menuContent': {
            templateUrl: 'templates/activities.html',
            controller: 'activitiesCtrl'
          }
        }
      })

      .state('app.activity', {
        url: '/activities/:activityId',
        views: {
          'menuContent': {
            templateUrl: 'templates/activity.html',
            controller: 'activityCtrl'
          }
        }
      })

      .state('app.news', {
        url: '/news',
        views: {
          'menuContent': {
            templateUrl: 'templates/news.html',
            controller: 'newsCtrl'
          }
        }
      })

      .state('app.singleNews', {
        url: '/news/:newsId',
        views: {
          'menuContent': {
            templateUrl: 'templates/singleNews.html',
            controller: 'singleNewsCtrl'
          }
        }
      })

      .state('app.gallery', {
        url: '/gallery',
        views: {
          'menuContent': {
            templateUrl: 'templates/gallery.html',
            controller: 'galleryCtrl'
          }
        }
      })
      .state('app.videos', {
        url: '/videos',
        views: {
          'menuContent': {
            templateUrl: 'templates/videos.html',
            controller: 'videoCtrl'
          }
        }
      })
      .state('app.social', {
        url: '/social',
        views: {
          'menuContent': {
            templateUrl: 'templates/social.html',
            controller: 'facebookCtrl'
          }
        }
      })
    ;
    // if none of the above states are matched, use this as the fallback
    $urlRouterProvider.otherwise('/app/home');
  });
