angular.module('gemfest.controllers', [])

  .controller('AppCtrl', function ($scope, $ionicModal, $timeout) {

    // With the new view caching in Ionic, Controllers are only called
    // when they are recreated or on app start, instead of every page change.
    // To listen for when this page is active (for example, to refresh data),
    // listen for the $ionicView.enter event:
    //$scope.$on('$ionicView.enter', function(e) {
    //});

    // Form data for the login modal
    $scope.loginData = {};

    // Create the login modal that we will use later
    $ionicModal.fromTemplateUrl('templates/login.html', {
      scope: $scope
    }).then(function (modal) {
      $scope.modal = modal;
    });

    // Triggered in the login modal to close it
    $scope.closeLogin = function () {
      $scope.modal.hide();
    };

    // Open the login modal
    $scope.login = function () {
      $scope.modal.show();
    };

    // Perform the login action when the user submits the login form
    $scope.doLogin = function () {
      console.log('Doing login', $scope.loginData);

      // Simulate a login delay. Remove this and replace with your login
      // code if using a login system
      $timeout(function () {
        $scope.closeLogin();
      }, 1000);
    };
  })

  .controller('homeCtrl', function ($scope, Artists, subscribeArtists, $rootScope, $ionicLoading, $http) {
    $scope.events = Artists.all('none');


    $scope.subscribeToArtist = function (id) {
      $scope.settings = angular.fromJson(window.localStorage.getItem('settings'));
      $scope.add = function () {
        if($scope.settings.notifications){
          var item = Artists.get(id);
          var artistStartTime = item.acf.artist_time.split('-');
          var alarmTime = new Date(item.acf.date + " " + artistStartTime[0]);
          alarmTime.setMinutes(alarmTime.getMinutes() - $scope.settings.time);
          $cordovaLocalNotification.schedule({
            id: id,
            at: alarmTime,
            text: item.acf.title + " starts in "+ $scope.settings.time +" minutes!",
            title: "Gemfest Reminder!",
            autoCancel: true,
            data: {
              type: 'artists',
              urlId: id
            }
          });
        }
      };
      $scope.isScheduled = function () {
        $cordovaLocalNotification.isScheduled(id).then(function (isScheduled) {
          alert("Notification " + id + " Scheduled: " + isScheduled);
        });
      }
      if (subscribeArtists.subscribe(id)) {
        $scope.add();
      } else {
        $cordovaLocalNotification.cancel(id);
      }
    };
    if ($scope.events.length < 1) {
      $ionicLoading.show({
        template: 'Loading...'
      }).then(function () {
        console.log("The loading indicator is now displayed");
      });
    }

    $scope.hideLoading = function () {
      $ionicLoading.hide().then(function () {
        console.log("The loading indicator is now hidden");
      });
    };
    $scope.subscribed = function (id) {
      return subscribeArtists.get(id);
    }
    $rootScope.$on('artistsCallFinished', function () {
      $scope.events = Artists.all();
      $scope.hideLoading();
    })
  })
  .controller('eventsCtrl', function ($scope) {
    $scope.events = [
      {title: 'Reggae', id: 1, image_url: '../img/list-cover.png'},
      {title: 'Chill', id: 2, image_url: '../img/list-cover.png'},
      {title: 'Dubstep', id: 3, image_url: '../img/list-cover.png'},
      {title: 'Indie', id: 4, image_url: '../img/list-cover.png'},
      {title: 'Rap', id: 5, image_url: '../img/list-cover.png'},
      {title: 'Cowbell', id: 6, image_url: '../img/list-cover.png'}
    ];
  })
  .controller('eventCtrl', function ($scope, $stateParams, Events) {
    $scope.item = Events.get($stateParams.eventId);
  })
  .controller('activitiesCtrl', function ($scope, Activities, subscribeActivities, $cordovaLocalNotification, $rootScope, $ionicLoading, $http) {
    $scope.activities = Activities.all('asc');
    $scope.order = {
      reverse: false
    };

    if ($scope.activities.length < 1) {
      $ionicLoading.show({
        template: 'Loading...'
      }).then(function () {
        console.log("The loading indicator is now displayed");
      });
    }

    $scope.hideLoading = function () {
      $ionicLoading.hide().then(function () {
        console.log("The loading indicator is now hidden");
      });
    };
    $scope.subscribedOnly = false;

    $rootScope.$on('activitiesCallFinished', function () {
      $scope.activities = Activities.all('asc');
      $scope.hideLoading();
    })

    $scope.sortModel = function () {
      if ($scope.order.reverse)
        $scope.order.reverse = false;
      else
        $scope.order.reverse = true;
    }

    $scope.filterSubscribed = function () {
      if ($scope.subscribedOnly)
        $scope.subscribedOnly = false;
      else
        $scope.subscribedOnly = true;
    }
    $scope.subscribeToActivity = function (id) {
      var lang = window.localStorage.getItem('settings');
      $scope.settings = angular.fromJson(window.localStorage.getItem('settings'));
      $scope.add = function () {
        if($scope.settings.notification){
          var item = Activities.get(id);
          var startTime = item.acf.activity_time.split('-');
          var alarmTime = new Date(item.acf.date + " " + startTime[0]);
          console.log('alarm Set on '+alarmTime);
          alarmTime.setMinutes(alarmTime.getMinutes() - $scope.settings.time);
          $cordovaLocalNotification.schedule({
            id: id,
            at: alarmTime,
            text: item.acf.title + " starts in " + $scope.settings.time +  " minutes!",
            title:"Gemfest Reminder!",
            autoCancel: true,
            data: {
              type: 'activities',
              urlId: id
            }
          });
        }
      };

      $rootScope.$on('artistsCallFinished', function () {
        $scope.events = Artists.all();
      })
      $scope.isScheduled = function () {
        $cordovaLocalNotification.isScheduled(id).then(function (isScheduled) {
          alert("Notification " + id + " Scheduled: " + isScheduled);
        });
      }
      if (subscribeActivities.subscribe(id)) {
        $scope.add();
      } else {
        $cordovaLocalNotification.cancel(id);
      }
    };
    $scope.subscribed = function (id) {
      return subscribeActivities.get(id);
    }
  })
  .controller('activityCtrl', function ($scope, $stateParams, Activities,$ionicLoading, subscribeActivities,SHARE_SERVICE , $cordovaLocalNotification, $rootScope) {
    var id = $stateParams.activityId;
    var weekday = ["Sun", "Mon", "Tues", "Wed", "Thur", "Fri", "Sat"];
    $scope.item = Activities.get(id);
    if ($scope.item ==  null) {
      $ionicLoading.show({
        template: 'Loading...'
      }).then(function () {
        console.log("The loading indicator is now displayed");
      });
    }
    if($scope.item != null){
      $scope.item.day = weekday[new Date($scope.item.acf.date).getDay()];
      $scope.item.time = $scope.item.acf.activity_time;
      console.log($scope.item);
    }
    $rootScope.$on('artistsCallFinished', function () {
      $scope.item = Activities.get(id);
      $scope.item.day = weekday[new Date($scope.item.acf.date).getDay()];
      $scope.item.time = $scope.item.acf.activity_time;
      $ionicLoading.hide();
    });
    var getActivity = function (id) {
      for (var i = 0; i < $scope.artists.length; i++) {
        if ($scope.artists[i].id == parseInt(id)) {
          return $scope.artists[i];
        }
      }
    }

    $scope.subscribeToActivity = function (id) {
      $scope.settings = angular.fromJson(window.localStorage.getItem('settings'));
      $scope.add = function () {
        if($scope.settings.notifications){
          var activity = Activities.get(id);
          var startTime = activity.acf.activity_time.split('-');
          var alarmTime = new Date(activity.acf.date + " " + startTime[0]);
          console.log('alarm Set on '+alarmTime);
          $cordovaLocalNotification.schedule({
            id: id,
            at: alarmTime,
            text: activity.acf.title + " starts in " + $scope.settings.time + " minutes!",
            title:" Gemfest Reminder!",
            autoCancel: true,
            data: {
              type: 'activities',
              urlId: id
            }
          });
        }
      };
      $scope.isScheduled = function () {
        $cordovaLocalNotification.isScheduled(id).then(function (isScheduled) {
          alert("Notification " + id + " Scheduled: " + isScheduled);
        });
      }

      $rootScope.$on('activitiesCallFinished', function () {
        Activities.all('none');
        $scope.item = Activities.get(id);
        $ionicLoading.hide();
        console.log($scope.item)
      })
      if (subscribeActivities.subscribe(id)) {
        $scope.add();
      } else {
        $cordovaLocalNotification.cancel(id);
      }
    };

    $scope.subscribed = function (id) {
      return subscribeActivities.get(id);
    }
    $scope.share = function () {
      console.log('Share Toggled');
      console.log($scope.item.link);
      SHARE_SERVICE.init(null,null,$scope.item.acf.share_image,null);
    }

    $scope.goToUrl = function (url) {
      console.log(url);
      $window.open(url, '_system');
      return false;
    }

  })

  .controller('lineupCtrl', function ($scope, Artists, subscribeArtists, $cordovaLocalNotification, $rootScope, $ionicLoading, $http) {
    $scope.artists = Artists.all('asc');
    $scope.order = {
      reverse: false
    };
    $scope.subscribedOnly = false;
    if ($scope.artists.length < 1) {
      $ionicLoading.show({
        template: 'Loading...'
      }).then(function () {
        console.log("The loading indicator is now displayed");
      });
    }

    $scope.hideLoading = function () {
      $ionicLoading.hide().then(function () {
        console.log("The loading indicator is now hidden");
      });
    };
    $scope.sortModel = function () {
      if ($scope.order.reverse)
        $scope.order.reverse = false;
      else
        $scope.order.reverse = true;
    }

    $scope.filterSubscribed = function () {
      if ($scope.subscribedOnly)
        $scope.subscribedOnly = false;
      else
        $scope.subscribedOnly = true;
    }

    $rootScope.$on('artistsCallFinished', function () {
      $scope.artists = Artists.all('asc');
      $scope.hideLoading();
    })
    $scope.subscribeToArtist = function (id) {
      $scope.settings = angular.fromJson(window.localStorage.getItem('settings'));
      $scope.add = function () {
        if($scope.settings.notifications){
          var item = Artists.get(id);
          var artistStartTime = item.acf.artist_time.split('-');
          var alarmTime = new Date(item.acf.date + " " + artistStartTime[0]);
          alarmTime.setMinutes(alarmTime.getMinutes() - $scope.settings.time);
          console.log(item.acf.date, artistStartTime[0],$scope.settings.time);
          console.log('alarm Set on '+alarmTime);
          $cordovaLocalNotification.schedule({
            id: id,
            at: alarmTime,
            text: item.acf.title + " starts in "+ $scope.settings.time +" minutes!",
            title: "Gemfest Reminder!",
            autoCancel: true,
            data: {
              type: 'artists',
              urlId: id
            }
          });
        }
      };
      $scope.isScheduled = function () {
        $cordovaLocalNotification.isScheduled(id).then(function (isScheduled) {
          alert("Notification " + id + " Scheduled: " + isScheduled);
        });
      }
      if (subscribeArtists.subscribe(id)) {
        $scope.add();
      } else {
        $cordovaLocalNotification.cancel(id);
      }
    };
    $scope.subscribed = function (id) {
      return subscribeArtists.get(id);
    }


  })
  .controller('artistCtrl', function ($scope, Artists, $stateParams,$ionicLoading, subscribeArtists,$window, $cordovaLocalNotification,$rootScope,SHARE_SERVICE) {
    var weekday = ["Sun", "Mon", "Tues", "Wed", "Thur", "Fri", "Sat"];
    $scope.item = Artists.get($stateParams.artistId);
    if ($scope.item ==  null) {
      $ionicLoading.show({
        template: 'Loading...'
      }).then(function () {
        console.log("The loading indicator is now displayed");
      });
    }
    if($scope.item != null){
      $scope.item.day = weekday[new Date($scope.item.acf.date).getDay()];
      $scope.item.time = $scope.item.acf.artist_time;
      console.log($scope.item);
    }
    $rootScope.$on('artistsCallFinished', function () {
      $scope.item = Artists.get($stateParams.artistId);
      $scope.item.day = weekday[new Date($scope.item.acf.date).getDay() ];
      $scope.item.time = $scope.item.acf.artist_time;
      $ionicLoading.hide();

    });
    $scope.subscribeToArtist = function (id) {
      $scope.settings = angular.fromJson(window.localStorage.getItem('settings'));
      $scope.add = function () {
        if($scope.settings.notifications){
          var artistStartTime = $scope.item.acf.artist_time.split('-');
          var alarmTime = new Date($scope.item.acf.date + " " + artistStartTime[0]);
          console.log(alarmTime.getMinutes());
          alarmTime.setMinutes(alarmTime.getMinutes() - $scope.settings.time);
          console.log('alarm Set on '+alarmTime);
          $cordovaLocalNotification.schedule({
            id: id,
            at: alarmTime,
            text: $scope.item.acf.title + " starts in "+ $scope.settings.time +" minutes!",
            title: "Gemfest Reminder!",
            data: {
              type: 'artists',
              urlId: id
            }
          });
        }
      };
      $scope.isScheduled = function () {
        $cordovaLocalNotification.isScheduled(id).then(function (isScheduled) {
          alert("Notification " + id + " Scheduled: " + isScheduled);
        });
      }
      if (subscribeArtists.subscribe(id)) {
        $scope.add();
      } else {
        $cordovaLocalNotification.cancel(id);
      }
    };
    $scope.subscribed = function (id) {
      return subscribeArtists.get(id);
    }
    $scope.share = function () {
      console.log('Share Toggled');
      console.log($scope.item.link);
      SHARE_SERVICE.init(null,null,$scope.item.acf.share_image,null);
    }
    $scope.goToUrl = function (url) {
      console.log(url);
      window.open(url, '_system','location=yes');
      return false;
    }
  })

  .controller('newsCtrl', function ($scope, News, $rootScope, $ionicLoading) {

    $ionicLoading.show({
      template: 'Loading...'
    }).then(function () {
      console.log("The loading indicator is now displayed");
    });
    $scope.news = News.all();

    $rootScope.$on('newsLoaded', function () {
      $scope.news = News.all();
      $ionicLoading.hide();
    })
  })
  .controller('singleNewsCtrl', function ($scope, News, $stateParams, $rootScope,SHARE_SERVICE ,$ionicLoading) {
    $scope.item = News.get($stateParams.newsId);
    var weekday = ["Sun", "Mon", "Tues", "Wed", "Thur", "Fri", "Sat"];
    if($scope.item != null){
      $scope.item.day = weekday[new Date($scope.item.acf.date).getDay() + 1];
      $scope.item.time = new Date($scope.item.acf.date).getTime();
    }
    $rootScope.$on('newsLoaded', function () {
      $scope.item = News.get($stateParams.newsId);
      $ionicLoading.hide();
      console.log($scope.item);
      $scope.item.day = weekday[new Date($scope.item.acf.date).getDay() + 1];
      $scope.item.time = new Date($scope.item.acf.date).getTime();
    });
    if ($scope.item ==  null) {
      $ionicLoading.show({
        template: 'Loading...'
      }).then(function () {
        console.log("The loading indicator is now displayed");
      });
    }
    $scope.share = function () {
      console.log('Share Toggled');
      console.log($scope.item.link);
      SHARE_SERVICE.init(null,null,$scope.item.acf.share_image,null);
    }
  })
  .controller('scheduleCtrl', function ($scope, Artists, $rootScope, $ionicLoading, $http, $state) {
    $scope.items = Artists.all();
    $scope.timeArray = [];

    $scope.stagesSchedule1 = [];
    $scope.stagesSchedule2 = [];
    $scope.stagesSchedule3 = [];
    $scope.stagesSchedule4 = [];
    $scope.stagesSchedule5 = [];
    for (var i = 0; i < 24; i++) {
      var genericString = '';

      if (i >= 10) {
        genericString = i + ":00";
      } else {
        genericString = "0" + i + ":00";
      }
      var leftUnit = 6240 / 24;
      var leftPosition = i * leftUnit;

      $scope.timeArray.push({time: genericString, left: leftPosition});
    }
    if ($scope.items.length < 1) {
      $ionicLoading.show({
        template: 'Loading...'
      }).then(function () {
        console.log("The loading indicator is now displayed");
      });
    }
    $scope.activeDate = 10;
    $scope.changeDate = function (num) {
      $ionicLoading.show({
        template: 'Loading...'
      }).then(function () {
        console.log("The loading indicator is now displayed");
      });
      $scope.activeDate = num;
      $http.get("http://gem-fest.com/wp-json/wp/v2/event?filter[posts_per_page]=-1")
        .then(function (response) {
          $scope.items = response.data;
          $scope.stagesSchedule1= [];
          $scope.stagesSchedule2= [];
          $scope.stagesSchedule3= [];
          $scope.stagesSchedule4= [];
          $scope.stagesSchedule5= [];
          $scope.items.forEach(function (item) {
            if(item.acf.artist_time != null){
              var startEndTimes = item.acf.artist_time.split('-');
              var artistStartTime = startEndTimes[0];
              var substr = artistStartTime.substr(0,2);
              var time = substr + ":00";
              item.startTime = time;
            }
            if(startEndTimes != undefined && startEndTimes.length>0){
              var startTime = parseInt(startEndTimes[0].substr(0,2));
              var endTime = parseInt(startEndTimes[0].substr(0,2));
              switch (endTime - startTime){
                case 2:
                      item.size = 'schedule-double';
                      break;
                case 3:
                      item.size = 'schedule-triple';
                      break;
                case 4:
                      item.size = 'schedule-quadruple';
                      break;
              }
            }
            var date = new Date(item.acf.date);
            if(date.getUTCDate()+1 == $scope.activeDate){
              switch (item.acf.stage.toLowerCase()){
                case 'main stage':
                  console.log(item);
                  $scope.stagesSchedule1.push(item);
                  break;
                case 'space bar stage':
                  $scope.stagesSchedule2.push(item);
                  break;
                case 'aquapark stage':
                  $scope.stagesSchedule3.push(item);
                  break;
                case "off stage":
                  $scope.stagesSchedule4.push(item);
                  break;
                case 'kimonoa stage':
                  $scope.stagesSchedule5.push(item);
                  break;
              }
            }
          });
          $ionicLoading.hide();
          console.log($scope.stagesSchedule1);
        });
    }
    $scope.changeDate(10);
    $scope.goToArtist = function (id) {
      $state.go("app.artist",{'artistId': id});
    }
    var scroll = document.getElementById('schedule-row-container');
    scroll.onscroll = function () {
      document.getElementById('scroll-left-fixed').style.left = scroll.scrollLeft + 'px';
      var time = document.getElementsByClassName('time-fixed-item');
      $scope.topPositions = {
        top:  scroll.scrollTop + 'px'
      }
      $scope.leftPositions = {
        left: scroll.scrollLeft +'px'
      }
      $scope.$apply();
    }
  })
  .controller('galleryCtrl', function ($scope, Images, Videos, $state,$http,$ionicLoading) {
    $scope.items = [];
    $http.get("http://gem-fest.com/wp-json/wp/v2/pages?slug=experience")
      .then(function(response) {
        var imageArray = response.data[0].acf.photo;
        imageArray.forEach(function (image) {
          $scope.items.push({src:image});
        })
      });
    $scope.goToVideos = function () {
      $state.go('app.videos');
    }
  })

  .controller('videoCtrl', function ($scope, Videos, $sce , $http,$ionicLoading) {
    $scope.videos = [];
    function GetVimeoIDbyUrl(url) {
      var arr = url.split('/');
      return (arr[arr.length-1]);
    }
    $http.get("http://gem-fest.com/wp-json/wp/v2/pages?slug=experience")
      .then(function(response) {
        var videoArray = response.data[0].acf.videos;
        videoArray.forEach(function (video) {
          var video_url  = video.video_link;
          var videoId = GetVimeoIDbyUrl(video_url);
          $scope.videos.push({src:videoId});
        })
        $scope.goToVideos = function () {
          $state.go('app.videos');
        }
        console.log($scope.videos);
      });
    $scope.trustSrc = function (src) {
      return $sce.trustAsResourceUrl(src);
    };

  })

  .controller('subscribedCtrl', function ($scope, subscribeActivities, subscribeArtists, Artists, Activities, $rootScope) {
    $scope.subscribed = [];
    $scope.listCanSwipe = true;

    var activities = subscribeActivities.all();
    var artists = subscribeArtists.all();
    $rootScope.$on('activitiesCallFinished', function () {
      $scope.artists = Artists.all('asc');
      activities.forEach(function (activity) {
        if (activity != null && activity > -1) {
          $scope.subscribed.push({type: 'activities', content: Activities.get(activity)});
        }
      });
    })
    $rootScope.$on('artistsCallFinished', function () {
      $scope.artists = Artists.all('asc');
      artists.forEach(function (artist) {
        if (artist != null && artist > -1) {
          $scope.subscribed.push({type: 'lineup', content: Artists.get(artist)});
        }
      });
    })
    $scope.$on('subscribed:updated', function () {
      $scope.subscribed = [];
      var activities = subscribeActivities.all();
      var artists = subscribeArtists.all();
      activities.forEach(function (activity) {
        if (activity != null && activity > -1) {
          $scope.subscribed.push({type: 'activities', content: Activities.get(activity)});
        }
      });
      artists.forEach(function (artist) {
        if (artist != null && artist > -1) {
          $scope.subscribed.push({type: 'lineup', content: Artists.get(artist)});
        }
      });
    });
    $scope.deleteSubscribed = function (type, id) {
      if (type === 'lineup') {
        subscribeArtists.subscribe(id);
      } else {
        subscribeActivities.subscribe(id);
      }
    }

  })
  .controller('settingsCtrl', function ($scope, $state) {

    $scope.data = angular.fromJson(window.localStorage.getItem('settings'));
    console.log($scope.data)
    if (window.localStorage.getItem('settings') != null && window.localStorage.getItem('settings') != 'null') {
      var settings = angular.fromJson(window.localStorage.getItem('settings'));
      $scope.data.notifications = settings.notifications;
      $scope.data.sound = settings.sound;
      $scope.data.reminder = settings.reminder;
    }
    window.localStorage.setItem('settings', angular.toJson($scope.data));

    $scope.updateSettings = function () {
      console.log($scope.data);
      window.localStorage.setItem('settings', angular.toJson($scope.data));
    }
    $scope.update = function () {
      var settings = angular.fromJson(window.localStorage.getItem('settings'));
      console.log($scope.data);
      window.localStorage.setItem('settings', angular.toJson($scope.data));
      window.location.reload(true)
    }

  })
  .controller('facebookCtrl', function ($scope,$window,deviceInfo,$sce) {

  })
  .controller('instagramCtrl', function ($scope) {

  })
  .controller('mapCtrl', function ($scope) {

  })
  .controller('langCtrl', function ($scope) {

    $scope.returnLanguage = function () {
      var lang = 'en-us';
      var settings = JSON.parse(window.localStorage.getItem('settings'));
      switch(settings.lang){
        case 'ka':
          lang = 'ka-ge';
          break;
        case 'ru':
          lang = 'ru-ru';
      }

      return lang;
    }
  });
