angular.module('gemfest.services', [])
  .service('subscribeArtists', function ($rootScope) {
    var subscribedArray = window.localStorage['artists'];
    if (subscribedArray === undefined)
      subscribedArray = [];
    else {
      subscribedArray = angular.fromJson(window.localStorage['artists']);
    }
    this.get = function (id) {
      if (subscribedArray.indexOf(id) > -1) {
        return true;
      } else {
        return false;
      }
    };
    this.all = function () {
      return subscribedArray;
    }
    this.subscribe = function (id) {
      if (subscribedArray.indexOf(id) > -1) {
        subscribedArray.splice(subscribedArray.indexOf(id), 1);
        window.localStorage['artists'] = angular.toJson(subscribedArray);
        $rootScope.$broadcast('subscribed:updated', this.all());
        return false;
      } else {
        subscribedArray.push(id);
        window.localStorage['artists'] = angular.toJson(subscribedArray);
        $rootScope.$broadcast('subscribed:updated', this.all());
        return true;
      }
    };
  })
  .service('subscribeActivities', function ($rootScope) {
    var subscribedArray = window.localStorage['activities'];
    if (subscribedArray === undefined)
      subscribedArray = [];
    else {
      subscribedArray = angular.fromJson(window.localStorage['activities']);
    }

    this.get = function (id) {
      if (subscribedArray.indexOf(id) > -1) {
        return true;
      } else {
        return false;
      }
    };
    this.all = function () {
      return subscribedArray;
    }
    this.subscribe = function (id) {
      if (subscribedArray.indexOf(id) > -1) {
        subscribedArray.splice(subscribedArray.indexOf(id), 1);
        window.localStorage['activities'] = angular.toJson(subscribedArray);
        $rootScope.$broadcast('subscribed:updated', this.all());
        return false;
      } else {
        subscribedArray.push(id);
        window.localStorage['activities'] = angular.toJson(subscribedArray);
        $rootScope.$broadcast('subscribed:updated', this.all());
        return true;
      }
    };
  })
  .factory('Videos', function () {

    // Some fake testing data
    var videos = [
      {
        src: 'https://player.vimeo.com/video/175576988',
      }];


    return {
      all: function () {
        return videos;
      },
      remove: function (video) {
        videos.splice(videos.indexOf(video), 1);
      },
      get: function (id) {
        for (var i = 0; i < videos.length; i++) {
          if (videos[i].id === parseInt(id)) {
            return videos[i];
          }
        }
        return null;
      },
      getFromTo: function (from, to) {
        var result = [];
        for (var i = from; i < to; i++) {
          if (videos[i] != undefined)
            result.push(videos[i]);
          else
            break
        }
        return result;
      }
    };
  }).factory('Images', function ($http) {

    // Some fake testing data
    var images = [];


    return {
      all: function () {
        return images;
      },
      remove: function (image) {
        images.splice(images.indexOf(image), 1);
      },
      get: function (id) {
        for (var i = 0; i < images.length; i++) {
          if (images[i].id === parseInt(id)) {
            return images[i];
          }
        }
        return null;
      },
      getFromTo: function (from, to) {
        var result = [];
        for (var i = from; i < to; i++) {
          if (images[i] != undefined)
            result.push(images[i]);
          else
            break
        }
        return result;
      }
    };
  })
  .factory('News', function ($http, $rootScope) {
    var settings = JSON.parse(window.localStorage.getItem('settings'));

    // Some fake testing data
    var thisObj = this;
    thisObj.news = [];
    var lang = settings.lang;
    if (lang == 'en')
      lang = '';
    $http.get("http://gem-fest.com/" + lang + "/wp-json/wp/v2/news?news[posts_per_page]=-1")
      .then(function (response) {
        thisObj.news = response.data;
        $rootScope.$broadcast('newsLoaded');
      });

    return {
      all: function () {
        return thisObj.news;
      },
      remove: function (singleNews) {
        thisObj.news.splice(thisObj.news.indexOf(singleNews), 1);
      },
      get: function (id) {
        for (var i = 0; i < thisObj.news.length; i++) {
          if (thisObj.news[i].id === parseInt(id)) {
            return thisObj.news[i];
          }
        }
        return null;
      }
    };
  })
  .factory('Artists', function ($http, $rootScope, $cordovaLocalNotification) {
    console.log();
    // Some fake testing data
    var settings = JSON.parse(window.localStorage.getItem('settings'));
    var thisObj = this;
    thisObj.artists = [];
    var lang = settings.lang;
    if (lang == 'en')
      lang = '';
    $http.get("http://gem-fest.com/" + lang + "/wp-json/wp/v2/event?filter[posts_per_page]=-1")
      .then(function (response) {
        thisObj.artists = response.data;
        $rootScope.$broadcast('artistsCallFinished');
        $cordovaLocalNotification.clearAll();
        var settings = JSON.parse(window.localStorage.getItem('settings'));
        var artists = JSON.parse(window.localStorage.getItem('artists'));
        if (artists != null)
          artists.forEach(function (id) {
            var data = response.data;
            var get = function (id) {
              for (var i = 0; i < data.length; i++) {
                if (data[i].id == parseInt(id)) {
                  return data[i];
                }
              }
              return null;
            };
            var item = get(id);
            var artistStartTime = item.acf.artist_time.split('-');
            var alarmTime = new Date(item.acf.date + " " + artistStartTime[0]);
            alarmTime.setMinutes(alarmTime.getMinutes() - settings.time);
            if (alarmTime > new Date()) {
              $cordovaLocalNotification.schedule({
                id: id,
                at: alarmTime,
                text: item.acf.title + " starts in " + settings.time + " minutes!",
                title: "Gemfest Reminder!",
                autoCancel: true,
                data: {
                  type: 'artists',
                  urlId: id
                }
              });
            }
          });
      });
    return {
      all: function (sorted) {
        if (sorted === 'none' || sorted === 'asc') {
          sorted = 'desc';
          thisObj.artists.sort(function (a, b) {
            var nameA = a.title.rendered.toLowerCase(), nameB = b.title.rendered.toLowerCase();
            if (nameA < nameB)
              return -1;
            if (nameA > nameB)
              return 1;
            return 0;
          });
        } else {
          sorted = 'asc';
          thisObj.artists.sort(function (a, b) {
            var nameA = a.title.rendered.toLowerCase(), nameB = b.title.rendered.toLowerCase();
            if (nameA > nameB)
              return -1;
            if (nameA < nameB)
              return 1;
            return 0;
          });
        }
        return thisObj.artists;
      },
      remove: function (artist) {
        thisObj.artists.splice(artists.indexOf(artist), 1);
      },
      get: function (id) {
        for (var i = 0; i < thisObj.artists.length; i++) {
          if (thisObj.artists[i].id == parseInt(id)) {
            return thisObj.artists[i];
          }
        }
        return null;
      }
    };
  })
  .factory('Activities', function ($http, $rootScope, $cordovaLocalNotification) {
    var settings = JSON.parse(window.localStorage.getItem('settings'));
    // Some fake testing data
    var thisObj = this;
    thisObj.activities = [];
    var lang = settings.lang;
    if (lang == 'en')
      lang = '';
    $http.get("http://gem-fest.com/" + lang + "/wp-json/wp/v2/activity?filter[posts_per_page]=-1")
      .then(function (response) {
        thisObj.activities = response.data;
        $rootScope.$broadcast('activitiesCallFinished');
        $cordovaLocalNotification.clearAll();
        var settings = JSON.parse(window.localStorage.getItem('settings'));
        var activities = JSON.parse(window.localStorage.getItem('activities'));
        if (activities != null)
          activities.forEach(function (id) {
            var data = response.data;
            var get = function (id) {
              for (var i = 0; i < data.length; i++) {
                if (data[i].id == parseInt(id)) {
                  return data[i];
                }
              }
              return null;
            };
            var item = get(id);
            var artistStartTime = item.acf.artist_time.split('-');
            var alarmTime = new Date(item.acf.date + " " + artistStartTime[0]);
            alarmTime.setMinutes(alarmTime.getMinutes() - settings.time);
            if (alarmTime > new Date()) {
              $cordovaLocalNotification.schedule({
                id: id,
                at: alarmTime,
                text: item.acf.title + " starts in " + settings.time + " minutes!",
                title: "Gemfest Reminder!",
                autoCancel: true,
                data: {
                  type: 'artists',
                  urlId: id
                }
              });
            }
          });
      });

    return {
      all: function (sorted) {
        if (sorted === 'none' || sorted === 'asc') {
          sorted = 'desc';
          thisObj.activities.sort(function (a, b) {
            var nameA = a.title.rendered.toLowerCase(), nameB = b.title.rendered.toLowerCase();
            if (nameA < nameB)
              return -1;
            if (nameA > nameB)
              return 1;
            return 0;
          });
        } else {
          sorted = 'asc';
          thisObj.activities.sort(function (a, b) {
            var nameA = a.title.rendered.toLowerCase(), nameB = b.title.rendered.toLowerCase();
            if (nameA > nameB)
              return -1;
            if (nameA < nameB)
              return 1;
            return 0;
          });
        }
        return thisObj.activities;
      },
      remove: function (activity) {
        thisObj.activities.splice(thisObj.activities.indexOf(activity), 1);
      },
      get: function (id) {
        for (var i = 0; i < thisObj.activities.length; i++) {
          if (thisObj.activities[i].id === parseInt(id)) {
            return thisObj.activities[i];
          }
        }
        return null;
      }
    };
  })
  .factory('deviceInfo', function ($window) {

    var data = {
      deviceWidth: $window.innerWidth,
      deviceHeight: $window.innerHeight,
    };


    return {
      get: function (index) {
        if (data[index] != undefined)
          return data[index];
        else
          return false;
      }
    };
  })
  .service('PUSH_NOTIFICATIONS', function ($ionicPlatform, $http, $rootScope, $window, $state) {
    this.init = function () {
      $ionicPlatform.ready(function () {

        var push = new Ionic.Push({
          "debug": true,
          "onNotification": function (notification) {
            var type = notification.payload.type;
            console.log(type);
            if (typeof type != 'undefined') {
              console.log(type + '--- Type in resume');
              if (type) {
                var locationId = notification.payload.id;
                if (type == 'events')
                  $state.go("app.artist", {'artistId': locationId});
                else if (type == 'activity')
                  $state.go("app.activity", {'activityId': locationId});
                else
                  $state.go("app.singleNews", {'activityId': locationId});
              }
            }
          }
        });

        var callback = function (token) {
          console.log("Device token:", token.token);
          push.saveToken(token);  // persist the token in the Ionic Platform
          $http({
            url: 'http://gem-fest.com/wp-content/plugins/plugin-base/admin/receiver.php',
            method: "GET",
            params: {device_token: token.token}
          });
        }
        push.register(callback);
      });
    }
  })
  .service('SHARE_SERVICE', function ($cordovaSocialSharing) {
    this.init = function (message, subject, image, link) {
      $cordovaSocialSharing
        .share(message, subject, image, link)
        .then(function (result) {
          // Success!
        }, function (err) {
          // An error occurred. Show a message to the user
        });
    }
  })
